# google

import ast
from functools import *
import os
from os import path
import sys

import localpackage
import X
from X import *
from X import A
from X import B, b, C, d
import Y
from Y import *
from Y import A
from Y import B, C, D
from Y import e
import Z
from Z import A
from Z.A import A
from Z.A.B import A

import flake8_import_order
from flake8_import_order import *
from . import A
from . import B
from .A import A
from .B import B
from .. import A
from .. import B
from ..A import A
from ..B import B

if TYPE_CHECKING:
    import ast
    from functools import *
    import os
    from os import path
    import sys

    import localpackage
    import X
    from X import *
    from X import A
    from X import B, b, C, d
    import Y
    from Y import *
    from Y import A
    from Y import B, C, D
    from Y import e
    import Z
    from Z import A
    from Z.A import A
    from Z.A.B import A

    import flake8_import_order
    from flake8_import_order import *
    from . import A
    from . import B
    from .A import A
    from .B import B
    from .. import A
    from .. import B
    from ..A import A
    from ..B import B
