# pycharm

import ast
import os
import sys
from functools import *
from os import path

import X
import Y
import Z
import localpackage
from X import *
from X import A
from X import B, C, b, d
from Y import *
from Y import A
from Y import B, C, D
from Y import e
from Z import A
from Z.A import A
from Z.A.B import A

import flake8_import_order
from flake8_import_order import *
from . import A
from . import B
from .A import A
from .B import B
from .. import A
from .. import B
from ..A import A
from ..B import B

if TYPE_CHECKING:
    import ast
    import os
    import sys
    from functools import *
    from os import path

    import X
    import Y
    import Z
    import localpackage
    from X import *
    from X import A
    from X import B, C, b, d
    from Y import *
    from Y import A
    from Y import B, C, D
    from Y import e
    from Z import A
    from Z.A import A
    from Z.A.B import A

    import flake8_import_order
    from flake8_import_order import *
    from . import A
    from . import B
    from .A import A
    from .B import B
    from .. import A
    from .. import B
    from ..A import A
    from ..B import B
