# appnexus edited google smarkets
import namespace
import namespace.package_a

import flake8_import_order
import namespace.package_b

if TYPE_CHECKING:
    import namespace
    import namespace.package_a

    import flake8_import_order
    import namespace.package_b
